"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createAuthServer = void 0;

var _express = _interopRequireDefault(require("express"));

var _bodyParser = _interopRequireDefault(require("body-parser"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { "default": obj }; }

// AuthenticationHandler mocking
var createAuthServer = function createAuthServer(doLog) {
  var app = (0, _express["default"])();
  var activeTokens = {};
  var currentTokenIndex = 0;
  var lastLoginId;
  app.use(_bodyParser["default"].urlencoded({
    extended: true
  }));
  app.use(_bodyParser["default"].json());
  app.get('/getAuthToken', function (req, res) {
    try {
      currentTokenIndex += 1;
      var token = "TOKEN".concat(currentTokenIndex);
      activeTokens[token] = setTimeout(function () {
        return delete activeTokens[token];
      }, 5000);
      if (doLog) console.log('Generated token:', token);
      res.status(201).json({
        token: token
      });
    } catch (err) {
      if (doLog) console.log('getAuthToken error:', err);
      res.status(500); // status Internal Server Error
    }
  });
  app.get('/lastLoginId', function (req, res) {
    try {
      res.status(201).json({
        lastLoginId: lastLoginId
      });
    } catch (err) {
      if (doLog) console.log('lastLoginId error:', err);
      res.status(500); // status Internal Server Error
    }
  });
  app.post('/authenticate', function (req, res) {
    try {
      // if (doLog) console.log('Auth req:', req.body);
      var _req$body$authData = req.body.authData,
          id = _req$body$authData.id,
          token = _req$body$authData.token;
      if (doLog) console.log('Auth from:', id, ', token:', token);

      if (id === 'testClient') {
        lastLoginId = id;
        return res.status(200).json({
          id: id,
          clientData: {
            id: id
          },
          serverData: {
            id: id,
            type: 'user'
          }
        });
      } // Service login


      if (token in activeTokens) {
        delete activeTokens[token];
        lastLoginId = id;
        return res.status(200).json({
          id: id,
          clientData: {
            id: id
          },
          serverData: {
            id: id,
            tokenAuth: true
          }
        });
      }

      if (doLog) console.log('Failed token login.');
      return res.status(401).send();
    } catch (err) {
      return res.status(500).send();
    }
  });
  return {
    app: app,
    server: undefined,
    start: function start() {
      this.server = app.listen(3000);
      return this;
    },
    stop: function stop() {
      this.server.close();
      return this;
    }
  };
};

exports.createAuthServer = createAuthServer;